(document:surround "/std/frame")
(po-domain "alterator-multiseat")
;;; Vars

;;; UI
(vbox align "top" margin 10
    (gridbox columns "30;70"
        (vbox
            (label text (_ "Workplaces"))
            (listbox name "seat_list" (when selected (seat-dev-update)))
        )
        (vbox 
            (hbox align "left" (label text (_ "Devices")) (label text (bold "seat0")))
            (checklistbox name "device_list")
            (hbox align "center"
                (button pixmap "theme:down" text (_ "Add") (when clicked (seat-dev-add)))
                (button pixmap "theme:up" text (_ "Remove") (when clicked (seat-dev-remove)))
            )
            (label text (_ "Workplace devices"))
            (checklistbox name "seat_dev_list")
        )

        (vbox
            (edit name "seatname" tooltip (_ "Seat names may consist only of a-z, A-Z, 0-9, \"-\" and \"_\" and must be prefixed with \"seat\"."))
            (hbox align "left"
                (button text (_ "Add") (when clicked (seat-add)))
                (button text (_ "Remove") (when clicked (seat-remove)))
                (button text (_ "Clear all") (when clicked (clear-all)))
                (button text (_ "Reset") (when clicked (act-config-reset)))
            )
            (checkbox name "pulse" text (_ "setup HDMI audio output"))
        )
        (spacer)
    )
    (separator)
    (hbox align "center"
        (button text (_ "Apply") (when clicked (act-activate)))
        (button text (_ "Cancel") (when clicked (device-flush)))
    )
)

;; Logic

(define (seat-new-name)
    (form-update-value "seatname" (woo-get-option (woo-read-first "/multiseat") 'seat_new_name))
)

(define (seat-add)
    (woo-write "/multiseat/seat_add" 'seatname (form-value "seatname"))
    (let ((cn (form-value "seatname")))
        (seat-new-name)
        (seat-update)
        (device-update)
        (form-update-value "seat_list" cn)
        (seat-dev-update)
    )
)

(define (seat-remove)
    (woo-write "/multiseat/seat_remove" 'seatname (form-value "seat_list"))
    (act-reset)
)

(define (seat-dev-add)
    (woo-write "/multiseat/seat_dev_add" 'seatname (form-value "seat_list") 'seatdev (form-value "device_list"))
    (act-reset)
)

(define (seat-dev-remove)
    (woo-write "/multiseat/seat_dev_remove" 'seatname (form-value "seat_list") 'seatdev (form-value "seat_dev_list"))
    (act-reset)
)

(define (seat-update)
    (let ((cn (form-value "seat_list")))
        (form-update-enum "seat_list" (woo-list "/multiseat/seat_list"))
        (form-update-value "seat_list" cn)
    )
)

(define (device-update)
    (form-update-enum "device_list" (woo-list "/multiseat/device_list"))
)

(define (device-flush)
    (woo-write "/multiseat/device_flush")
    (act-reset)
)

(define (clear-all)
    (woo-write "/multiseat/seat_rm_all")
    (act-reset)
)

(define (seat-dev-update)
    (form-update-enum "seat_dev_list" (woo-list "/multiseat/seat_dev_list" 'seatname (form-value "seat_list")))
)

(define (act-activate)
    (if (eq? 'yes (document:popup-question (_ "Apply changes and restart the computer? Should any problems arise, run the following command in the terminal:<br> <strong>loginctl flush-devices</strong>") 'yes 'no))
        (woo-write "/multiseat/activate" 'pulse (form-value "pulse"))
    )
)

(define (act-reset)
    (seat-new-name)
    (device-update)
    (seat-update)
    (seat-dev-update)
    (let ((data (woo-read-first "/multiseat")))
        (form-update-value "pulse" (woo-get-option data 'pulse))
        (form-update-visibility "pulse" (woo-get-option data 'pulse_visible))
    )
)

(define (act-config-reset)
    (woo-write "/multiseat/reset")
    (act-reset)
)

(document:root
    (when loaded
        (act-config-reset)
    )
)
